==============================
``psyclone.psyir.backend.sir``
==============================

.. automodule:: psyclone.psyir.backend.sir

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.backend.sir
